@@ -5,7 +5,7 @@ use warnings;
 use Getopt::Long 'GetOptions';
 use Exporter ();
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 our @ISA = 'Exporter';
 our @EXPORT = 'GetOptions';
@@ -15,8 +15,7 @@ my @config = qw(default gnu_getopt no_auto_abbrev no_ignore_case);
 sub import {
 	my $class = shift;
 	$class->export_to_level(1, $class, 'GetOptions');
-	Getopt::Long::Configure(@config);
-	Getopt::Long::Configure(@_) if @_;
+	Getopt::Long::Configure(@config, @_);
 }
 
 1;
@@ -45,7 +44,6 @@ Only the C<GetOptions> function from L<Getopt::Long> is exported. Additional
 L<Getopt::Long> configuration may be passed as import parameters.
 
  use Getopt::Long::Modern qw(auto_help auto_version pass_through);
- # perl 5.8.1+ or Getopt::Long 2.33+ required for auto_help and auto_version
 
 For any more advanced usage, you should probably use L<Getopt::Long> directly.
 
